@@ -17,7 +17,10 @@ def _dpkg_query_local(pkg):
     cmd = _dpkg_query_cmd(pkg)
     try:
         with open(os.devnull, 'w') as devnull:
-            output = subprocess.check_output(cmd, stderr=devnull)
+            output = subprocess.Popen(
+                    cmd,
+                    stdout=subprocess.PIPE,
+                    stderr=devnull).communicate()[0]
         return output
     except subprocess.CalledProcessError, e:
         if e.returncode == 1:  # package not installed
@@ -45,8 +48,8 @@ def _dpkg_status(dpkg_query_output):
 
 
 def key_exists(key_id, keyring='/etc/apt/trusted.gpg'):
-    out = subprocess.check_output(['gpg', '--list-keys', '--primary-keyring',
-                                  keyring])
+    command = ['gpg', '--list-keys', '--primary-keyring', keyring]
+    out = subprocess.Popen(command, stdout=subprocess.PIPE).communicate()[0]
     lines = out.split("\n")
     return any(key_id in l for l in lines)
 
@@ -62,7 +65,7 @@ def import_key(keyserver, key_id):
 
 def _source_list_path(list_name):
     filename = list_name if list_name.endswith('list') else list_name + ".list"
-    return '/etc/apt/sources.list.d/{}'.format(filename)
+    return '/etc/apt/sources.list.d/{0}'.format(filename)
 
 
 def add_source_list(list_name, lines):
@@ -80,7 +83,7 @@ def rm_source_list(list_name):
 
 def status(pkgs):
     """Return the install status of the given packages."""
-    return {p: _dpkg_status(_dpkg_query_local(p)) for p in pkgs}
+    return dict((p, _dpkg_status(_dpkg_query_local(p))) for p in pkgs)
 
 
 def _install(pkgs):
