@@ -15,7 +15,7 @@ def has_key_pair(key_pair, require=False):
 
     if require and not success:
         print("""
-Error: unable to find key-pair '{}'.
+Error: unable to find key-pair '{0}'.
 Perhaps the key-pair does not exist, or you do not have access to it?
 (You can check this with `aws ec2 describe-key-pairs`.)
 """.strip().format(key_pair))
@@ -26,14 +26,15 @@ Perhaps the key-pair does not exist, or you do not have access to it?
 def has_bucket(bucket, require=False):
     with open("/dev/null", 'w') as devnull:
         cmd = [aws_cmd, 's3api', 'list-buckets']
-        output = subprocess.check_output(cmd, stderr=devnull)
+        output = subprocess.Popen(
+                cmd, stderr=devnull, stdout=subprocess.PIPE).communicate()[0]
     buckets = json.loads(output)['Buckets']
     bkt_names = [bkt['Name'] for bkt in buckets]
     success = bucket in bkt_names
 
     if require and not success:
         print("""
-    Error: unable to find bucket '{}'.
+    Error: unable to find bucket '{0}'.
     Perhaps the bucket does not exist, or you do not have access to it?
     (You can check this with `aws s3api list-buckets`.)
     """.strip().format(bucket))
@@ -42,15 +43,16 @@ def has_bucket(bucket, require=False):
 
 
 def has_s3_object(bucket, path, require=False):
-    s3_obj = "s3://{}/{}".format(bucket, path.lstrip("/"))
+    s3_obj = "s3://{0}/{1}".format(bucket, path.lstrip("/"))
     with open("/dev/null", 'w') as devnull:
         cmd = [aws_cmd, 's3', 'ls', s3_obj]
-        output = subprocess.check_output(cmd, stderr=devnull)
+        output = subprocess.Popen(
+                cmd, stderr=devnull, stdout=subprocess.PIPE).communicate()[0]
     success = len(output) > 0
 
     if require and not success:
         print("""
-Error: unable to find S3 object '{}' in bucket '{}'.
+Error: unable to find S3 object '{0}' in bucket '{1}'.
 Perhaps the bucket or file does not exist, or you do not have access to it?
 (You can check this with `aws s3api list-buckets` and `aws s3 ls S3_PATH`.)
 """.strip().format(path, bucket))
